@@ -28,25 +28,14 @@ def check_type(argname: str, value: object, expected_type: typing.Any) -> typing
             else:
                 typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore
 
-import aws_cdk.aws_autoscaling._jsii
-import aws_cdk.aws_autoscaling_hooktargets._jsii
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.aws_s3_assets._jsii
-import aws_cdk.aws_sns._jsii
-import aws_cdk.aws_sns_subscriptions._jsii
-import aws_cdk.core._jsii
-import aws_cdk.custom_resources._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-gitlab-runner",
-    "1.115.1429",
+    "2.2.266",
     __name__[0:-6],
-    "cdk-gitlab-runner@1.115.1429.jsii.tgz",
+    "cdk-gitlab-runner@2.2.266.jsii.tgz",
 )
 
 __all__ = [
